
# q-expansion of newform 8008.2.a.l, downloaded from the LMFDB on 14 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 8008
weight = 2
poly_data = [1, -2, -18, -10, 24, 12, -9, -2, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0], 1], [[-3, 9, 10, -7, -2, 1, 0, 0], 2], [[-6, -9, 21, 12, -9, -2, 1, 0], 2], [[-2, -12, -9, 23, 12, -9, -2, 1], 2], [[-1, -34, -26, 47, 25, -18, -4, 2], 2], [[-8, 19, 59, -41, -51, 22, 8, -3], 2], [[-1, 27, 51, -42, -50, 22, 8, -3], 2], [[-15, 31, 76, -63, -64, 31, 10, -4], 2]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 1, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 1, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0], [1, 0, 1, -1, 0, 0, 0, 0], [-2, -1, 0, 0, 0, 0, 1, 1], [-1, 0, -1, 1, -1, 0, 0, -1], [-1, 1, 1, -2, 2, -2, -1, 0], [0, 2, -1, 0, 0, -1, -1, 1], [0, -1, 1, -1, 0, -2, -1, 1], [-3, 1, -1, 2, -1, 3, 1, -1], [-1, 1, 0, -2, 2, -3, 0, 0], [-1, 0, 1, 1, 1, 0, 0, -1], [-4, 1, -2, -1, -2, 0, -1, 0], [-1, -1, 0, 0, 2, -1, 0, 1], [-1, 0, 0, 1, -1, 0, 3, 0], [-2, 2, 1, -2, 0, -3, -1, 0], [0, -3, -1, 2, 1, 0, 0, -1], [0, -1, 0, -1, 0, 1, 2, -2], [1, 0, -1, 0, 0, 0, -1, 1], [-1, -2, 1, 2, -1, -1, 1, 0], [2, 2, -1, -2, 1, 0, -3, -1], [3, 0, 0, -1, 0, -1, -2, 0], [-3, -2, -1, 0, -1, 3, 1, 0], [0, 2, 2, 0, 0, -3, 0, 1], [-2, -2, -1, 2, 0, 0, 0, 1], [4, -2, 0, -5, 0, 0, 1, 0], [1, 4, 0, -2, 0, -1, -2, 0], [-2, 2, -1, 3, 0, -1, 1, -1], [-7, 3, 1, -4, -1, -1, -1, -1], [-1, 3, 0, -2, -2, -2, 1, 0], [-1, 1, -1, -2, 2, 0, -2, 0], [0, 2, 2, -3, 1, -1, 1, 3], [0, 3, 0, -3, -1, -3, -1, 0], [-3, -2, 1, -1, 2, 1, 1, 0], [0, -7, 0, 0, -1, 3, 2, -2], [0, 0, 1, 4, 2, -1, 2, 0], [-6, 0, 1, -3, -1, 4, -1, 0], [-1, -1, -2, 0, -2, 4, 0, -2], [-6, 0, -2, 6, 1, 3, 0, -3], [1, 3, 0, -2, -2, 3, 1, 1], [7, -1, -1, -4, 0, 0, -3, -1], [0, -1, 0, 1, -1, 2, -2, 0], [0, -3, 0, -2, -2, -1, 0, 4], [-3, 2, -1, 7, 1, 2, 2, 0], [3, -1, 5, -4, 4, -5, -3, 1], [-11, 5, -1, 6, 0, 1, -1, 0], [-3, -3, -1, 1, -2, 2, 2, -4], [-1, -3, 4, -4, 4, -2, 2, 0], [6, 0, 5, -2, 1, 0, 1, 0], [6, 4, -3, -4, 0, 3, -1, 1], [-2, 1, -1, -2, -3, -2, 2, 3], [-5, 0, -2, -1, 2, 3, -3, -4], [7, 0, 1, -4, 2, -3, 1, 2], [-12, 5, -5, -1, -2, 4, -3, -3], [-7, -5, -4, 6, -3, 6, 0, -1], [-4, -1, 1, 1, -1, 3, 1, 0], [2, -1, -3, -1, 2, 2, 1, -2], [1, -3, 2, 0, 1, 2, 0, 2], [-1, -6, 3, 3, 0, 3, 2, 0], [-8, -8, 2, 0, -1, 1, 3, 0], [-3, 1, -2, 1, -3, -1, -4, 1], [-15, 0, -1, 7, -2, 6, 4, -1], [9, -3, 3, 0, 3, -3, 2, 1], [-9, 5, 0, 1, -2, 0, 0, 0], [-1, 4, -6, 5, -2, -1, 1, -2], [-6, -3, -1, -2, -5, 2, -1, 1], [-17, 2, -2, 3, -6, 8, 4, -5], [0, -2, -2, 0, -2, 6, 2, -2], [-12, 3, -7, 3, -5, 5, -1, -4], [2, -7, 4, 3, 1, 0, 1, 2], [2, -1, 0, -1, 4, -3, 0, 2], [-19, 2, -3, -1, -2, 0, 1, 0], [-2, -1, -1, 3, -1, 2, 0, -3], [-6, 1, 0, 4, -1, 0, 4, 1], [3, 2, 2, -3, 1, -4, -4, -2], [-13, -1, -1, 4, 0, 6, 1, -4], [12, -6, 4, -4, -1, -1, -2, 1], [-19, 2, -2, 5, 0, 2, 4, 0], [2, 5, 0, 5, 1, -2, -3, -1], [4, -4, 3, 0, -1, -1, 0, 5], [1, 0, -1, 5, -3, 9, 1, -4], [1, -5, 2, -4, -1, 1, 6, -1], [-15, -3, 0, 4, 0, 2, -3, 0], [3, 3, 5, -6, 3, -10, -5, 4], [4, 5, 0, -2, 0, -8, -5, 7], [-4, 0, -3, 4, 1, 1, -1, -1], [-7, -3, -1, 2, -3, -2, -2, -2], [-8, -3, -1, 9, 1, 1, 0, 1], [-3, -2, 2, 8, 3, -1, 3, 4], [-2, 7, -1, -1, -2, 2, 2, -3], [-14, 3, -5, 1, 2, 3, 0, 0], [0, -1, 2, -4, -4, 2, -2, 3], [-7, -6, 2, -5, 0, 1, 2, -2], [-5, -5, -1, 6, -5, 3, 4, -1], [-4, -2, -3, 2, -4, 7, 0, 1], [-5, 2, 6, -1, 5, -7, 0, 0], [-3, -1, 3, 0, -3, -3, 4, -1], [-13, 0, -4, 9, -2, 5, -2, -4], [2, 1, 5, -2, 2, -1, -1, 4], [-2, 1, 0, -5, -1, 0, -3, -3], [-2, 1, 0, 3, 1, 0, -1, 5], [3, 4, -4, -6, 2, -5, 1, -2], [14, -3, 0, 3, 5, 6, 1, -4], [-20, 5, -9, -3, -7, 7, -1, -4], [7, 1, 0, 4, 6, -9, -1, 3], [-2, -3, -3, 7, 1, 6, 0, -1], [8, 8, -1, 0, 9, -4, -4, 1], [1, -6, 3, 5, 5, 0, -1, -1], [-6, 0, -2, 0, -3, 3, 4, -5], [-4, 5, 4, 3, 3, -11, -3, 4], [-7, 6, 2, -5, -1, 1, -2, -4], [10, -4, 4, -4, 5, -3, -4, 2], [-7, 1, 1, 6, 2, 2, -2, 1], [-2, 6, -9, 12, -7, 3, 1, -1], [17, -6, 8, -11, 11, -14, -2, 9], [15, -1, 0, 0, 4, -4, -1, -1], [11, -1, 4, -10, -1, -5, 2, 8], [3, -6, 0, 0, -2, 5, 2, -6], [0, 6, 1, 4, -3, -3, -1, 3], [-19, 2, -2, 11, -1, 5, -3, -3], [2, -7, 0, 9, 5, -1, 3, 3], [-6, 8, 2, -6, 0, -6, -7, -2], [3, 0, -1, 5, -2, 0, -3, 3], [11, 5, 5, -10, -1, -3, 1, -1], [-1, 1, 0, 0, -7, 12, 5, -7], [-2, -7, 0, 14, 1, 6, 0, 1], [9, 6, -2, -5, -4, -11, -1, 6], [6, -7, 8, -9, 0, -7, -5, 6], [-4, 0, 1, 12, 5, -1, 6, 1], [19, -5, 7, -2, 2, 3, -1, -3], [0, -2, -5, 13, -7, 6, 6, -4], [8, -6, 2, 2, 5, -10, -3, 2], [8, -10, 2, -4, 0, -1, 5, 3], [-3, 4, 2, 1, 3, 0, 4, 2], [-2, 1, -3, 13, -7, 5, 5, -1], [-14, -4, -3, 8, -6, 11, 5, -1], [-3, -4, -2, 1, -8, 10, 0, -5], [6, -3, 10, -8, 0, -8, -5, 3], [12, 3, -4, 5, -4, 1, -2, -3], [22, -1, 3, -5, 1, -7, -2, 4], [-17, 6, 3, 5, 2, -2, 2, 1], [2, 11, -4, -15, -2, -2, -5, -3], [-18, -2, -7, -2, -7, 5, 6, -1], [-22, -1, 0, 11, 4, -1, 2, 0], [8, 0, -2, -1, -10, 7, -3, -1], [-19, -5, -5, 4, -9, 6, 0, 0], [11, -2, 8, -1, -1, 2, 0, 3], [-2, 1, -4, -1, 2, -6, -4, -4], [-25, -1, -8, 0, -8, 0, 3, -4], [6, 5, 5, -9, 2, -10, -2, 9], [-2, 0, 3, 8, 2, -4, 6, 6], [-5, 5, -1, 0, -1, 2, -5, -8], [-5, 2, 5, 5, -4, 6, -1, -1], [-5, -1, -1, -2, 8, 3, -1, 0], [-32, -1, 0, 7, -5, 6, 3, -2], [2, -4, 4, -3, -8, 4, 7, 0], [21, -6, -4, 1, -4, 1, 1, 0], [-24, -5, -2, 13, -9, 9, 3, -1], [-4, -2, 4, -10, 7, -10, 1, 0], [5, -9, 0, 14, -2, 7, 9, -1], [-2, -3, 1, -2, 1, 1, -2, 4], [-12, 0, 6, 4, 7, -9, 0, -1], [0, -3, -6, 3, 3, -2, 2, -1], [1, -12, 2, -1, 6, 2, 3, 1], [8, 8, 1, -5, 6, -6, 1, -2], [11, 7, -4, 1, -2, -1, -5, -1], [1, 2, 7, 1, 6, -10, -2, 1], [26, -8, 6, -4, 1, -4, 2, 6], [8, 5, 3, 1, 0, -4, -2, 1], [-4, -1, 0, -12, 5, -6, 1, 3], [-5, 14, -4, 1, 4, 2, -5, 2], [18, 5, 2, -1, -2, 3, 3, 1], [8, 7, 2, -3, -3, -7, -1, 6], [2, -8, -2, -6, 1, -2, 4, 0], [-9, -3, 6, 6, 4, 0, -1, -2], [5, 1, 3, -14, 8, -15, -1, 3], [6, 3, 2, 4, 3, 5, -3, -8], [6, 9, 5, -2, 1, -15, 0, 12], [-1, -5, 5, -6, 12, -11, 1, 3], [23, 3, 6, 5, 11, 1, 2, 1], [-17, -1, -8, 6, -11, 5, 5, -3], [-1, -1, -9, 2, 0, 10, 8, -5], [-5, -11, 1, 6, 9, -1, 2, 5], [-11, 4, 1, 9, -2, 2, 6, 3], [-1, 1, -2, -6, -7, -4, -6, 0], [6, 8, -5, 3, -3, 2, -1, -10], [10, -7, 1, -13, 5, 4, 2, -1], [11, -9, -1, 12, -2, 13, 1, -1], [-3, 6, -7, 5, -1, 5, 1, -8], [-1, -1, 3, 6, -4, 2, -1, 2], [-9, 0, -2, -3, 3, -1, 8, 3], [-2, -3, 3, -11, 0, -2, 0, -5], [-17, -4, -5, -1, -2, 7, 6, 4], [-8, 2, -6, 6, 7, 3, 5, -6], [-7, 5, -12, 6, 2, -1, 1, -6], [-3, -12, 3, 5, 2, 3, 4, 4], [-20, 5, 2, 7, 6, -5, 2, 0], [0, -8, -1, -2, -2, -2, -6, -5], [12, 6, -7, -4, -3, 6, -4, 4], [-16, -2, 10, 5, 9, -1, 6, -3], [-7, 2, -4, -2, 1, 4, -5, -3], [4, 2, 6, -16, 4, -10, -4, 2], [1, 6, 6, 5, 2, -7, -3, 2], [-9, 6, -6, -1, -1, 2, -6, 7], [-28, 8, -4, 6, 2, 7, -2, 1], [-9, 1, 4, 15, 4, -3, -3, -5], [9, 7, 1, -3, -2, -3, 4, -3], [2, -2, 7, -12, -3, 1, -5, 7], [6, -8, 2, 2, 0, 10, -6, 0], [28, 0, -2, 2, -9, 10, -2, -2], [0, 9, -3, 3, 7, 0, -9, 1], [9, 13, 1, -3, -1, -12, 3, 4], [1, -4, 9, -2, 9, -6, 8, 1], [9, 1, -1, 6, -1, 10, -3, -7], [1, -11, -1, 8, -1, 12, 2, -2], [-17, 4, -10, 15, 1, 2, -2, 2], [-10, 9, -6, 7, 0, 2, -6, -5], [23, -5, 2, -4, 6, 3, 0, 1], [-6, -12, 6, 4, 0, 3, -2, 7], [4, -9, 5, 1, 9, 1, -2, -2], [4, 3, -5, -8, -5, 1, 4, 0], [-2, -11, 0, 5, 3, 2, -1, 5], [1, -6, 7, 11, 3, 16, 3, -9], [-10, -3, -6, 11, -5, 13, 4, -12], [19, 0, -1, -1, -4, 6, 2, 7], [-16, -5, -3, 1, -3, -8, -1, -5], [4, -7, 6, -3, -3, 3, 1, -2], [15, -7, 2, -4, 0, -1, -5, 2], [12, -7, -1, 11, 2, 10, 8, -1], [10, -2, 2, -12, 10, 3, -3, 9], [-12, 1, -9, 11, 3, 0, -3, -7], [-14, 14, -6, -3, -7, -1, -2, -3], [-9, 1, 2, -4, 2, -2, 4, 5], [8, 20, 0, -6, 3, -7, -4, -1], [-7, -4, 2, 4, 12, -2, 7, 3], [13, 3, -2, -12, 3, 0, -5, 10], [25, 4, 11, 3, 9, -18, -1, 6], [-15, 15, -7, 2, -5, 5, -4, -3], [8, 1, 3, 13, 4, 3, 3, 6], [32, -2, 3, -12, -3, 12, -1, -9], [-16, 4, -1, 18, 1, -9, 0, 3], [1, 15, 7, -4, -3, -10, -8, 0], [15, -13, 8, -12, 2, -8, 1, 6], [24, -7, -6, -5, -9, 12, 0, 1], [13, 14, -3, 5, 8, -11, -7, 4], [-4, 10, -7, 8, -7, 10, 0, -6], [17, -2, 12, -9, 5, -11, -6, 6], [-13, 4, -6, 2, -5, 4, 5, 1], [8, -4, 2, -4, -5, 4, 1, 8], [-20, 5, -5, 1, 0, 2, -12, 2], [-4, -5, -7, 19, -8, 19, 6, -2], [-4, 6, -5, -9, 6, -13, -1, -1], [-14, -16, 4, 0, -3, 9, 3, 5], [3, -3, -2, 10, 3, 11, 1, 6], [9, 6, -1, -12, -6, -4, -3, 7], [-1, 6, 1, 1, -3, 5, -11, 0], [16, -4, -1, 14, -7, 10, 7, -4], [2, -15, 1, -5, -5, -6, 7, 10], [31, 2, 11, -5, 12, -8, -6, 4], [20, -1, -8, 1, -1, 10, 6, -3], [5, -12, 7, -8, 4, 4, -5, 7], [-19, -10, 7, -3, 7, -6, -1, 4], [-1, -20, 6, 5, 6, 2, 8, 0], [7, -4, -5, 1, 3, 2, 3, -7], [-25, 8, -9, 9, -4, 7, 3, 1], [-22, 12, -4, 4, -7, 1, -5, 1], [-6, 3, -3, -5, 4, 7, 2, 2], [22, -11, 8, -17, 2, -8, 2, 5], [11, 4, -3, -12, 9, -8, 0, -1], [15, 5, 6, 1, 4, 4, -8, -2], [11, -3, -1, -10, -5, -7, -5, 8], [-19, -2, 11, 3, 3, 10, 4, -2], [-10, 11, 2, 3, 11, -12, 1, -7], [14, -5, 6, -12, -3, -6, -10, 7], [-6, -6, -5, 18, -15, 27, 4, -8], [31, -1, 11, -16, 6, -13, -4, 5], [-18, 5, 7, -11, -7, 6, -1, 1], [2, 13, -4, -23, -3, -14, -6, 3], [12, 8, 14, -9, 16, -20, 0, 2], [-19, 1, -4, 2, -12, 1, -1, -5], [-18, 8, -10, -4, -1, 12, -3, -2], [-13, -11, 9, -18, -1, 5, -1, 2], [1, -1, -5, -2, -9, 10, -6, -6], [-14, 10, -4, 3, -11, -2, 8, -8], [-19, 14, -15, 9, -7, 17, 2, -9], [30, -2, 3, 0, -7, 3, -3, -3], [17, 0, 15, -1, -2, -2, -2, 8], [3, 3, -3, 4, -5, 2, 8, -4], [-9, 2, -8, 11, 10, -5, 2, -4], [-3, 0, -3, 8, 13, -5, 5, -6], [-6, -16, -1, -3, -5, 16, 3, -6], [-12, 15, -4, 1, 1, -6, 2, 1], [-11, 12, 4, -9, 2, -8, -6, -3], [-4, 0, 7, 6, 1, -6, -1, 9], [-15, 4, -3, 7, 0, -4, 3, -3], [16, -5, 3, -7, -5, -8, 1, 1], [-5, 14, 0, -1, -12, 7, -2, -4], [5, -4, 6, 7, -2, -12, -4, -7], [3, 3, 4, 4, -2, -11, 2, 0], [31, 1, 1, 0, -5, 12, 4, -2], [-2, -6, -3, 4, 1, 8, 6, -10], [0, 1, 1, 11, 2, 3, -6, -6], [-1, -13, 1, 8, -6, 3, 7, 1], [3, 4, -6, -3, -9, -11, -1, 2], [-5, 9, 2, -10, 2, 5, -7, -5], [-4, 7, -5, 8, -10, 0, 0, -9], [3, 5, -5, 8, -7, -7, 4, -7], [5, 2, 2, -3, -6, -5, -5, 10], [18, 16, -6, -10, 9, -7, -11, -7], [-9, 2, -2, -17, -3, -1, -11, -2], [-7, -10, -1, 21, -3, 9, 6, 4], [-21, 7, -13, 2, -7, 8, 3, -10], [9, 8, 4, -32, 6, -17, -3, 6], [18, -4, -7, 2, -1, 7, 8, 3], [-9, 11, -6, -8, 2, -1, -8, 1], [-21, 16, -5, 6, 1, 4, -4, -7], [-2, -2, -5, -14, 4, -3, -1, 1], [6, 3, -6, -9, 1, -6, -5, 1], [45, -11, 5, 0, 10, -13, 1, 9], [-26, -4, -2, -2, 0, -8, 5, -9], [4, 6, -8, 14, -4, 5, -8, 2], [-20, -3, 1, 3, 13, -7, -1, -3], [-12, -4, -6, -4, -7, 5, 2, -5], [-21, 5, 0, 0, 4, 9, -9, -4], [27, -8, -1, 1, 10, 6, -5, 1], [12, 7, 0, -2, 2, -4, -7, -1], [7, 3, -2, 2, 13, -9, -12, -1], [-1, 4, -9, 1, 1, 9, 2, 3], [-15, 9, 4, 9, -9, -6, -2, 4], [-31, 5, -20, 2, -4, 8, 4, -2], [4, -1, 4, 22, 11, 5, 1, -4], [39, 5, 5, -8, 1, -4, -1, 4], [5, 1, 5, 20, -5, 10, 0, 4], [6, -8, 5, -2, 15, -7, 6, 7], [7, -17, 2, -10, 2, 2, -1, -4], [2, -10, -7, 23, -8, 8, 10, 2], [-26, 21, 8, 1, 5, -14, 2, 5], [7, -19, -1, -2, 0, 2, 12, 8], [-11, 14, 2, -9, 7, -20, 0, 1], [16, 9, 2, -1, -4, -19, -3, 4], [0, 14, 10, -4, 9, -16, 3, 4], [-7, 7, 5, -22, -2, -7, -8, 3], [4, 2, -10, 19, -5, 5, -5, -9], [-2, -5, -4, 13, 13, 5, 6, 0], [24, -10, 4, -10, 0, -8, 2, 10], [-14, 3, -13, 13, -3, 2, -4, 7], [-9, 6, -2, -9, 1, -3, -3, -8], [-29, 13, -1, 12, 6, -11, 3, 0], [22, -2, 3, 12, 4, 8, 4, -6], [19, 11, 1, 16, -1, 5, -2, 9], [12, -21, -5, 5, -13, 16, 9, 1], [-16, 1, 5, -7, 1, -3, -8, 14], [28, 4, 6, 6, -3, 7, 4, 9], [-1, -6, -4, 5, -2, -10, 6, -5], [-15, 5, -1, 20, 3, 3, 12, -3], [-1, -8, 9, -5, 5, -9, -3, 4], [-21, 17, -11, 29, -5, 8, -2, -8], [-21, 7, -12, 10, -5, 15, -2, -12], [-14, -10, -4, -11, -13, 7, 7, 5], [-7, -3, -3, 6, -8, 8, 17, -2], [-34, 0, 0, 18, 2, 19, 9, -9], [6, 8, -8, 0, -12, -6, -2, 1], [23, -4, 4, -18, 9, -8, -10, 7], [-2, -17, 4, 5, -2, -4, 3, 9], [-27, -7, 3, 12, -10, 5, 2, 1], [-38, 3, -5, 5, 2, -10, 2, 7], [-41, -11, -4, 6, 2, 21, 3, -9], [1, -16, 0, -16, -2, 8, 2, -3], [-18, -8, 10, 18, -1, -1, 15, 5], [-15, -16, 1, 5, -8, 14, 12, -1], [10, 5, 7, 3, 3, 2, -13, -5], [3, 11, 4, -26, -6, -11, -5, -8], [-16, 11, -8, 5, 0, 2, 0, -11], [10, 10, 3, -15, -9, -4, -1, 8], [19, -3, 4, -4, -12, -1, 5, 13], [-6, 7, -2, -1, 15, -16, -4, 2], [11, 0, 10, 4, 5, -11, 9, 12], [22, 9, 7, -12, -12, 2, 0, -1], [7, 0, -9, 1, 10, 6, -2, 1], [-26, -1, 0, 15, 4, -2, 7, 3], [-15, -5, 4, -5, 4, 11, -5, 1], [-7, -8, 8, -19, 7, 5, -4, 4], [-14, 2, -6, 6, -2, 19, 0, -5], [7, -3, 7, 2, 14, 10, 0, 2], [-3, -11, 3, 24, -2, 14, -2, -4], [-12, -2, -7, 30, 0, 4, 0, 4], [11, -8, 15, -2, 0, -10, 4, -5], [-6, 18, -3, 2, -10, -1, -9, -9], [-17, 2, 8, 7, -1, 13, 2, -2], [18, 1, 0, 5, 6, 12, 5, -10], [4, -8, 2, 1, 4, -5, 4, 7], [19, 6, 2, -7, -9, 2, 4, 0], [28, -4, 8, -14, 18, -15, -4, 11], [9, 8, 12, -12, 10, -15, -1, 14], [-29, 0, 3, -3, 2, -4, -1, -5], [1, -23, 7, 4, 8, -1, -3, 7], [-3, -19, 1, -7, -9, 3, 17, 3], [-7, -7, -2, -2, -16, -6, 7, 8], [-7, 5, 7, 10, 15, -5, 2, -2], [-26, 3, -3, -5, 7, -5, -10, -4], [-34, 2, -7, -10, -3, -2, 11, -3], [-21, 14, -5, 5, 3, -6, -3, -1], [-4, -10, -5, 4, -7, 13, 2, 5], [11, 6, 16, -3, 12, -24, -5, 1], [8, -1, 14, -14, 10, -4, -7, 9], [2, 6, 1, -6, -5, 1, -10, 1], [18, 3, 16, -17, 12, -11, 5, 2], [-4, -17, -1, -6, -10, 6, 3, -3], [16, -6, -5, -2, -12, 9, -5, -1], [19, -23, 4, -10, 1, -2, 6, 6], [-19, 22, 4, -14, -11, -9, -5, -4], [-4, -11, 3, -1, -8, -9, -4, -2], [-2, -16, 1, -6, -1, -2, 10, 0], [13, -20, 7, -9, -5, 6, 6, 1], [7, 1, 2, 13, 13, 7, 4, -1], [16, -9, 18, -20, 11, -21, -16, 6], [5, 10, 3, 9, 12, -18, -11, 3], [-26, 9, 0, -22, -1, -1, -12, -2], [-12, -11, -6, 1, -10, 6, 4, -3], [7, -4, 0, -6, -4, -8, -12, 7], [-11, -6, -3, -9, 7, -4, 0, -3], [-20, 2, -11, 20, 2, -5, -1, 4], [13, 11, -11, -13, 3, -9, -12, 3], [5, -3, -3, 8, -5, 7, 6, 5], [41, 8, -5, -2, -1, -2, -9, -1], [-18, 11, 1, -11, 14, -7, -19, -10], [-2, 6, -4, -12, 6, 6, -5, -8]]
